@@ -14,8 +14,8 @@ def pull_hplc_data_from_folder(folder, targets, wiggle=0.01, watchfor='Report.TX
     Pulls the HPLC integrations for all report files within the specified directory.
     This function was designed to pull all data from a given day. This method only pulls data which exists in the reports,
     which can result in asymmetric data for timepoint analysis (i.e. it assumes that subsequent runs are unrelated to
-     others). If the data in a folder are for time-course analysis, use
-     :py:currentmodule:`~aghplctools.hplc.pull_hplc_data_from_folder_timepoint`.
+    others). If the data in a folder are for time-course analysis, use
+    :func:`~aghplctools.hplc.pull_hplc_data_from_folder_timepoint`.
 
 
     :param folder: The folder to search for report files
