@@ -44,6 +44,30 @@ _prefix_re = re.compile('(?P<prefix>.+)ACAML')
 _agilent_dt_re = re.compile('(?P<dt>.+)[-+].+')
 
 
+def strptime_agilent_dt(dt_string: str) -> datetime.datetime:
+    """
+    Performs strptime on Agilent datetime string
+
+    :param dt_string: agilent datetime strings
+    :return: parsed datetime object
+    """
+    observed_formats = [
+        '%Y-%m-%dT%H:%M:%S.%f',  # with ms value
+        '%Y-%m-%dT%H:%M:%S',  # w/o ms value
+    ]
+    for fmt in observed_formats:
+        try:
+            match = _agilent_dt_re.match(dt_string)
+            return datetime.datetime.strptime(
+                match.group('dt'),
+                fmt
+            )
+        except ValueError:
+            continue
+    raise ValueError(f'The provided datetime string "{dt_string}" does not match any expected formats')
+
+
+
 class DADSignalInfo(object):
     # default unit for wavelength values
     DEFAULT_WAVELENGTH_UNIT = 'nm'
@@ -294,12 +318,9 @@ class HPLCSampleInfo(object):
                         f'{"Multiple" if len(seq_files) > 1 else "No"}'
                         f' sequence.acam_ files were found in the directory "{acaml}". Please refine your search.'
                     )
-                acaml = os.path.join(
-                    acaml,
-                    seq_files[0]
-                )
+                acaml = acaml / seq_files[0]
             else:
-                if _acaml_re.search(acaml) is None:
+                if _acaml_re.search(acaml.suffix) is None:
                     # todo consider trying to parse anyway
                     raise ValueError(f'The file "{acaml}" does not have a valid extension')
             acaml = xml.etree.ElementTree.parse(
@@ -311,10 +332,7 @@ class HPLCSampleInfo(object):
 
         # extract creation date
         cd = [val for val in root.iter(f'{prefix}CreationDate')][0]
-        dt = datetime.datetime.strptime(
-            _agilent_dt_re.match(cd.text).group('dt'),
-            '%Y-%m-%dT%H:%M:%S.%f'
-        )
+        dt = strptime_agilent_dt(cd.text)
 
         # extract method name
         method = [val for val in root.iter(f'{prefix}Method')][0]
